@@ -54,7 +54,7 @@ class SubRipTime(Comparable):
     TIME_PATTERN = '%02d:%02d:%02d,%03d'
     TIME_REPR = 'SubRipTime(%d, %d, %d, %d)'
     RE_TIME = re.compile(r'(?P<hours>\d{2}):(?P<minutes>\d{2}):'
-                         r'(?P<seconds>\d{2}),(?P<milliseconds>\d{3})')
+                         r'(?P<seconds>\d{2})[,\.](?P<milliseconds>\d{3})')
     SECONDS_RATIO = 1000
     MINUTES_RATIO = SECONDS_RATIO * 60
     HOURS_RATIO = MINUTES_RATIO * 60
@@ -102,6 +102,13 @@ class SubRipTime(Comparable):
         self.ordinal -= self._coerce(other).ordinal
         return self
 
+    def __mul__(self, ratio):
+        return self.from_ordinal(int(round(self.ordinal * ratio)))
+
+    def __imul__(self, ratio):
+        self.ordinal = int(round(self.ordinal * ratio))
+        return self
+
     @classmethod
     def _coerce(cls, other):
         """
@@ -138,6 +145,8 @@ class SubRipTime(Comparable):
 
         All arguments are optional and have a default value of 0.
         """
+        if 'ratio' in kwargs:
+            self *= kwargs.pop('ratio')
         self += self.__class__(*args, **kwargs)
 
     @classmethod
